@@ -13,19 +13,19 @@
 #define RENDERER_H
 
 #include "playfield.h"
-
+// KDEGames
+#include <KGameRenderer>
+// Qt
+#include <QPixmap>
 #include <QPainter>
 #include <QString>
 #include <QSize>
 
-class QPixmap;
-class RendererPrivate;
-
-class Renderer {
+class Renderer : public KGameRenderer
+{
 	private:
 		Renderer();
-		Renderer(const Renderer &);
-		~Renderer();
+
 	public:
 		static Renderer *self();
 
@@ -40,15 +40,17 @@ class Renderer {
 		QPixmap background();
 		QPixmap messageBox(const QString &message);
 
-		void resetPlayField();
 		void drawPart(QPainter & painter, int x, int y, const QString &svgName);
 		void updatePlayField(PlayField &playfield);
 		QPixmap *getPlayField();
-
-		QPixmap pixmapFromCache(RendererPrivate *p, const QString &svgName, const QSize &size);
+		void clearPixmapCache();
 
     private:
-		RendererPrivate *p;
+		QSize m_sceneSize;
+		QSize m_partSize;
+
+		QPixmap m_playField;
+		QPixmap m_background;
 };
 
 #endif // RENDERER_H
